Export Package VRC : bcB50Pc pre 
Update compared VRC:   B50 c ca20
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : Yes
Library sources    : No
Total file size    : 1890131
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
tbcstc014                           B50Pc pre
tbcsts004                           B50Pc pre
sbcstc0106m000                      B50Pc pre
sbcstc0114m000                      B50Pc pre
pbcdllfbcttf020                     B50Pc pre (without source)
pbcdllfbcttf021                     B50Pc pre (without source)
pbcdllfbcttf022                     B50Pc pre (without source)
pbcdllfcisli100                     B50Pc pre (without source)
pbcdllfcisli120                     B50Pc pre (without source)
pbcdllfcisli200                     B50Pc pre (without source)
pbcdllfcisli201                     B50Pc pre (without source)
pbcdllfcisli225                     B50Pc pre (without source)
pbcdllfcisli235                     B50Pc pre (without source)
pbcdllfcisli240                     B50Pc pre (without source)
pbcdllfcisli245                     B50Pc pre (without source)
pbcdllfcisli255                     B50Pc pre (without source)
pbcdllfcisli265                     B50Pc pre (without source)
pbcdllfcprao020                     B50Pc pre (without source)
pbcdllfcprrp100                     B50Pc pre (without source)
pbcdllfecedi702                     B50Pc pre (without source)
pbcdllfqmptc100                     B50Pc pre (without source)
pbcdllfqmptc120                     B50Pc pre (without source)
pbcdllfqmptc230                     B50Pc pre (without source)
pbcdllfqmptc301                     B50Pc pre (without source)
pbcdllfqmptc305                     B50Pc pre (without source)
pbcdllftccom000                     B50Pc pre (without source)
pbcdllftccom110                     B50Pc pre (without source)
pbcdllftccom140                     B50Pc pre (without source)
pbcdllftccom145                     B50Pc pre (without source)
pbcdllftccom700                     B50Pc pre (without source)
pbcdllftccom999                     B50Pc pre (without source)
pbcdllftcemm000                     B50Pc pre (without source)
pbcdllftcibd001                     B50Pc pre (without source)
pbcdllftcibd002                     B50Pc pre (without source)
pbcdllftcibd200                     B50Pc pre (without source)
pbcdllftcmcs000                     B50Pc pre (without source)
pbcdllftcmcs001                     B50Pc pre (without source)
pbcdllftcmcs055                     B50Pc pre (without source)
pbcdllftcmcs120                     B50Pc pre (without source)
pbcdllftcmcs121                     B50Pc pre (without source)
pbcdllftcmcs122                     B50Pc pre (without source)
pbcdllftcmcs123                     B50Pc pre (without source)
pbcdllftctax000                     B50Pc pre (without source)
pbcdllftctax601                     B50Pc pre (without source)
pbcdllftctax603                     B50Pc pre (without source)
pbcdllftdipu010                     B50Pc pre (without source)
pbcdllftdpcg000                     B50Pc pre (without source)
pbcdllftdpcg031                     B50Pc pre (without source)
pbcdllftdpur000                     B50Pc pre (without source)
pbcdllftdpur400                     B50Pc pre (without source)
pbcdllftdsls000                     B50Pc pre (without source)
pbcdllftdsls027                     B50Pc pre (without source)
pbcdllftdsls028                     B50Pc pre (without source)
pbcdllftdsls150                     B50Pc pre (without source)
pbcdllftdsls301                     B50Pc pre (without source)
pbcdllftdsls351                     B50Pc pre (without source)
pbcdllftdsls400                     B50Pc pre (without source)
pbcdllftdsls450                     B50Pc pre (without source)
pbcdllftdsls451                     B50Pc pre (without source)
pbcdllftdsmi002                     B50Pc pre (without source)
pbcdllftdsmi003                     B50Pc pre (without source)
pbcdllftdsmi040                     B50Pc pre (without source)
pbcdllftdsmi054                     B50Pc pre (without source)
pbcdllftdsmi101                     B50Pc pre (without source)
pbcdllftdsmi110                     B50Pc pre (without source)
pbcdllftdsmi111                     B50Pc pre (without source)
pbcdllftdsmi121                     B50Pc pre (without source)
pbcdllftdsmi201                     B50Pc pre (without source)
pbcdllftdsmi206                     B50Pc pre (without source)
pbcdllftdsmi210                     B50Pc pre (without source)
pbcdllftfacp002                     B50Pc pre (without source)
pbcdllftfacp200                     B50Pc pre (without source)
pbcdllftfacr200                     B50Pc pre (without source)
pbcdllftfcmg000                     B50Pc pre (without source)
pbcdllftfcmg006                     B50Pc pre (without source)
pbcdllftffam000                     B50Pc pre (without source)
pbcdllftffam100                     B50Pc pre (without source)
pbcdllftffam110                     B50Pc pre (without source)
pbcdllftffam120                     B50Pc pre (without source)
pbcdllftffam200                     B50Pc pre (without source)
pbcdllftffam520                     B50Pc pre (without source)
pbcdllftffam650                     B50Pc pre (without source)
pbcdllftffam710                     B50Pc pre (without source)
pbcdllftffam775                     B50Pc pre (without source)
pbcdllftffam800                     B50Pc pre (without source)
pbcdllftffam807                     B50Pc pre (without source)
pbcdllftffam808                     B50Pc pre (without source)
pbcdllftffam810                     B50Pc pre (without source)
pbcdllftffam830                     B50Pc pre (without source)
pbcdllftffam840                     B50Pc pre (without source)
pbcdllftffst120                     B50Pc pre (without source)
pbcdllftfgld004                     B50Pc pre (without source)
pbcdllftfgld102                     B50Pc pre (without source)
pbcdllftfgld106                     B50Pc pre (without source)
pbcdllftfgld107                     B50Pc pre (without source)
pbcdllftfgld110                     B50Pc pre (without source)
pbcdllftiedm000                     B50Pc pre (without source)
pbcdllftiedm010                     B50Pc pre (without source)
pbcdllftiedm120                     B50Pc pre (without source)
pbcdllftipcf000                     B50Pc pre (without source)
pbcdllftipcf320                     B50Pc pre (without source)
pbcdllftipcs030                     B50Pc pre (without source)
pbcdllftipcs400                     B50Pc pre (without source)
pbcdllftipcs420                     B50Pc pre (without source)
pbcdllftirou000                     B50Pc pre (without source)
pbcdllftirou102                     B50Pc pre (without source)
pbcdllftisfc000                     B50Pc pre (without source)
pbcdllftisfc001                     B50Pc pre (without source)
pbcdllftisfc010                     B50Pc pre (without source)
pbcdllftppdm600                     B50Pc pre (without source)
pbcdllftpppc000                     B50Pc pre (without source)
pbcdllftpppc210                     B50Pc pre (without source)
pbcdllftppss200                     B50Pc pre (without source)
pbcdllftsctm199                     B50Pc pre (without source)
pbcdllftsctm200                     B50Pc pre (without source)
pbcdllftsctm300                     B50Pc pre (without source)
pbcdllftsctm410                     B50Pc pre (without source)
pbcdllftsctm810                     B50Pc pre (without source)
pbcdllftsctm811                     B50Pc pre (without source)
pbcdllftssoc000                     B50Pc pre (without source)
pbcdllftssoc100                     B50Pc pre (without source)
pbcdllftssoc200                     B50Pc pre (without source)
pbcdllftssoc810                     B50Pc pre (without source)
pbcdllftssoc850                     B50Pc pre (without source)
pbcdllfwhinh000                     B50Pc pre (without source)
pbcdllfwhinh010                     B50Pc pre (without source)
pbcdllfwhinh225                     B50Pc pre (without source)
pbcdllfwhinh250                     B50Pc pre (without source)
pbcdllfwhinh270                     B50Pc pre (without source)
pbcdllfwhinh400                     B50Pc pre (without source)
pbcdllfwhinh450                     B50Pc pre (without source)
pbcdllfwhinh460                     B50Pc pre (without source)
pbcdllfwhinr130                     B50Pc pre (without source)
pbcdllfwhltc300                     B50Pc pre (without source)
pbcdllfwhltc500                     B50Pc pre (without source)
pbcdllfwhltc510                     B50Pc pre (without source)
pbcdllfwhwmd000                     B50Pc pre (without source)
pbcdllfwhwmd220                     B50Pc pre (without source)
pbcdllfwhwmd405                     B50Pc pre (without source)
pbcdllmbptmm200                     B50Pc pre (without source)
pbcdllmcisli205                     B50Pc pre (without source)
pbcdllmtcccp060                     B50Pc pre (without source)
pbcdllmtcmcs003                     B50Pc pre (without source)
pbcdllmtcppl100                     B50Pc pre (without source)
pbcdllmtdpur401                     B50Pc pre (without source)
pbcdllmtdsls401                     B50Pc pre (without source)
pbcdllmtdsmi200                     B50Pc pre (without source)
pbcdllmtdsta000                     B50Pc pre (without source)
pbcdllmtfacp245                     B50Pc pre (without source)
pbcdllmtfacp251                     B50Pc pre (without source)
pbcdllmtfgld008                     B50Pc pre (without source)
pbcdllmtssoc220                     B50Pc pre (without source)
pbcdllmtssoc860                     B50Pc pre (without source)
pbcdllmwhinh200                     B50Pc pre (without source)
pbcdllmwhinh211                     B50Pc pre (without source)
pbcdllmwhinh220                     B50Pc pre (without source)
pbcdllmwhinh430                     B50Pc pre (without source)
pbcdllmwhinh431                     B50Pc pre (without source)
pbcdllmwhinh451                     B50Pc pre (without source)
pbcgct3gltest                       B50Pc pre (without source)
pbcintdll0000                       B50Pc pre (without source)
pbcintdll0005                       B50Pc pre (without source)
pbcintdll0007                       B50Pc pre (without source)
pbcintdll0009                       B50Pc pre (without source)
pbcsbp000                           B50Pc pre (without source)
pbcstc0100                          B50Pc pre (without source)
pbcstc0114                          B50Pc pre (without source)
pbcstc014                           B50Pc pre (without source)
pbcstcdll0007                       B50Pc pre (without source)
pbcstcdll0008                       B50Pc pre (without source)
fbcstc0114m00012                    B50Pc pre
cbcstc00053                         B50Pc pre
cbcstc00054                         B50Pc pre
cbcstc00055                         B50Pc pre
cbcstc00056                         B50Pc pre
cbcstc00057                         B50Pc pre
cbcstc00058                         B50Pc pre
mbcstc0000100112                    B50Pc pre
obcdllfbcttf020                     B50Pc pre
obcdllfbcttf021                     B50Pc pre
obcdllfbcttf022                     B50Pc pre
obcdllfcisli100                     B50Pc pre
obcdllfcisli120                     B50Pc pre
obcdllfcisli200                     B50Pc pre
obcdllfcisli201                     B50Pc pre
obcdllfcisli225                     B50Pc pre
obcdllfcisli235                     B50Pc pre
obcdllfcisli240                     B50Pc pre
obcdllfcisli245                     B50Pc pre
obcdllfcisli255                     B50Pc pre
obcdllfcisli265                     B50Pc pre
obcdllfcprao020                     B50Pc pre
obcdllfcprrp100                     B50Pc pre
obcdllfecedi702                     B50Pc pre
obcdllfqmptc100                     B50Pc pre
obcdllfqmptc120                     B50Pc pre
obcdllfqmptc230                     B50Pc pre
obcdllfqmptc301                     B50Pc pre
obcdllfqmptc305                     B50Pc pre
obcdllftccom000                     B50Pc pre
obcdllftccom110                     B50Pc pre
obcdllftccom140                     B50Pc pre
obcdllftccom145                     B50Pc pre
obcdllftccom700                     B50Pc pre
obcdllftccom999                     B50Pc pre
obcdllftcemm000                     B50Pc pre
obcdllftcibd001                     B50Pc pre
obcdllftcibd002                     B50Pc pre
obcdllftcibd200                     B50Pc pre
obcdllftcmcs000                     B50Pc pre
obcdllftcmcs001                     B50Pc pre
obcdllftcmcs055                     B50Pc pre
obcdllftcmcs120                     B50Pc pre
obcdllftcmcs121                     B50Pc pre
obcdllftcmcs122                     B50Pc pre
obcdllftcmcs123                     B50Pc pre
obcdllftctax000                     B50Pc pre
obcdllftctax601                     B50Pc pre
obcdllftctax603                     B50Pc pre
obcdllftdipu010                     B50Pc pre
obcdllftdpcg000                     B50Pc pre
obcdllftdpcg031                     B50Pc pre
obcdllftdpur000                     B50Pc pre
obcdllftdpur400                     B50Pc pre
obcdllftdsls000                     B50Pc pre
obcdllftdsls027                     B50Pc pre
obcdllftdsls028                     B50Pc pre
obcdllftdsls150                     B50Pc pre
obcdllftdsls301                     B50Pc pre
obcdllftdsls351                     B50Pc pre
obcdllftdsls400                     B50Pc pre
obcdllftdsls450                     B50Pc pre
obcdllftdsls451                     B50Pc pre
obcdllftdsmi002                     B50Pc pre
obcdllftdsmi003                     B50Pc pre
obcdllftdsmi040                     B50Pc pre
obcdllftdsmi054                     B50Pc pre
obcdllftdsmi101                     B50Pc pre
obcdllftdsmi110                     B50Pc pre
obcdllftdsmi111                     B50Pc pre
obcdllftdsmi121                     B50Pc pre
obcdllftdsmi201                     B50Pc pre
obcdllftdsmi206                     B50Pc pre
obcdllftdsmi210                     B50Pc pre
obcdllftfacp002                     B50Pc pre
obcdllftfacp200                     B50Pc pre
obcdllftfacr200                     B50Pc pre
obcdllftfcmg000                     B50Pc pre
obcdllftfcmg006                     B50Pc pre
obcdllftffam000                     B50Pc pre
obcdllftffam100                     B50Pc pre
obcdllftffam110                     B50Pc pre
obcdllftffam120                     B50Pc pre
obcdllftffam200                     B50Pc pre
obcdllftffam520                     B50Pc pre
obcdllftffam650                     B50Pc pre
obcdllftffam710                     B50Pc pre
obcdllftffam775                     B50Pc pre
obcdllftffam800                     B50Pc pre
obcdllftffam807                     B50Pc pre
obcdllftffam808                     B50Pc pre
obcdllftffam810                     B50Pc pre
obcdllftffam830                     B50Pc pre
obcdllftffam840                     B50Pc pre
obcdllftffst120                     B50Pc pre
obcdllftfgld004                     B50Pc pre
obcdllftfgld102                     B50Pc pre
obcdllftfgld106                     B50Pc pre
obcdllftfgld107                     B50Pc pre
obcdllftfgld110                     B50Pc pre
obcdllftiedm000                     B50Pc pre
obcdllftiedm010                     B50Pc pre
obcdllftiedm120                     B50Pc pre
obcdllftipcf000                     B50Pc pre
obcdllftipcf320                     B50Pc pre
obcdllftipcs030                     B50Pc pre
obcdllftipcs400                     B50Pc pre
obcdllftipcs420                     B50Pc pre
obcdllftirou000                     B50Pc pre
obcdllftirou102                     B50Pc pre
obcdllftisfc000                     B50Pc pre
obcdllftisfc001                     B50Pc pre
obcdllftisfc010                     B50Pc pre
obcdllftppdm600                     B50Pc pre
obcdllftpppc000                     B50Pc pre
obcdllftpppc210                     B50Pc pre
obcdllftppss200                     B50Pc pre
obcdllftsctm199                     B50Pc pre
obcdllftsctm200                     B50Pc pre
obcdllftsctm300                     B50Pc pre
obcdllftsctm410                     B50Pc pre
obcdllftsctm810                     B50Pc pre
obcdllftsctm811                     B50Pc pre
obcdllftssoc000                     B50Pc pre
obcdllftssoc100                     B50Pc pre
obcdllftssoc200                     B50Pc pre
obcdllftssoc810                     B50Pc pre
obcdllftssoc850                     B50Pc pre
obcdllfwhinh000                     B50Pc pre
obcdllfwhinh010                     B50Pc pre
obcdllfwhinh225                     B50Pc pre
obcdllfwhinh250                     B50Pc pre
obcdllfwhinh270                     B50Pc pre
obcdllfwhinh400                     B50Pc pre
obcdllfwhinh450                     B50Pc pre
obcdllfwhinh460                     B50Pc pre
obcdllfwhinr130                     B50Pc pre
obcdllfwhltc300                     B50Pc pre
obcdllfwhltc500                     B50Pc pre
obcdllfwhltc510                     B50Pc pre
obcdllfwhwmd000                     B50Pc pre
obcdllfwhwmd220                     B50Pc pre
obcdllfwhwmd405                     B50Pc pre
obcdllmbptmm200                     B50Pc pre
obcdllmcisli205                     B50Pc pre
obcdllmtcccp060                     B50Pc pre
obcdllmtcmcs003                     B50Pc pre
obcdllmtcppl100                     B50Pc pre
obcdllmtdpur401                     B50Pc pre
obcdllmtdsls401                     B50Pc pre
obcdllmtdsmi200                     B50Pc pre
obcdllmtdsta000                     B50Pc pre
obcdllmtfacp245                     B50Pc pre
obcdllmtfacp251                     B50Pc pre
obcdllmtfgld008                     B50Pc pre
obcdllmtssoc220                     B50Pc pre
obcdllmtssoc860                     B50Pc pre
obcdllmwhinh200                     B50Pc pre
obcdllmwhinh211                     B50Pc pre
obcdllmwhinh220                     B50Pc pre
obcdllmwhinh430                     B50Pc pre
obcdllmwhinh431                     B50Pc pre
obcdllmwhinh451                     B50Pc pre
obcgct3gltest                       B50Pc pre
obcintdll0000                       B50Pc pre
obcintdll0005                       B50Pc pre
obcintdll0007                       B50Pc pre
obcintdll0009                       B50Pc pre
obcsbp000                           B50Pc pre
obcstc0100                          B50Pc pre
obcstc0114                          B50Pc pre
obcstc014                           B50Pc pre
obcstcdll0007                       B50Pc pre
obcstcdll0008                       B50Pc pre
lbcbcstc014.appr                    B50Pc pre
lbcbcstc014.ccty                    B50Pc pre
lbcbcstc014.cmpl                    B50Pc pre
lbcbcstc014.cvat                    B50Pc pre
lbcbcstc014.expi                    B50Pc pre
lbcbcstc014.fcmp                    B50Pc pre
lbcbcstc014.ncty                    B50Pc pre
lbcbcstc014.nvat                    B50Pc pre
lbcbcstc014.smpl                    B50Pc pre
lbcbcstc014.tvat                    B50Pc pre
Fbccnv0200s00012                    B50Pc pre
Fbccnv02991    2                    B50Pc pre
Fbccnv0299m00012                    B50Pc pre
Fbccnv0401m00012                    B50Pc pre
Fbccnv250m0001 2                    B50Pc pre
Fbccnv42231    2                    B50Pc pre
Fbccnv4223m00012                    B50Pc pre
Fbccnv4233m00012                    B50Pc pre
Fbccnv4233m000d2                    B50Pc pre
Fbccnv4520m00012                    B50Pc pre
Fbccnv5501m00012                    B50Pc pre
Fbccnv5501m00022                    B50Pc pre
Fbccnv6400m00012                    B50Pc pre
Fbccnv8101m00012                    B50Pc pre
Fbccnv8201m00012                    B50Pc pre
Fbccnv8201s00012                    B50Pc pre
Fbccnv8201s00112                    B50Pc pre
Fbccnv8201s00212                    B50Pc pre
Fbccnv8203m00012                    B50Pc pre
Fbccnv8403m00012                    B50Pc pre
Fbccnv8403m000d2                    B50Pc pre
Fbccnv8403m00112                    B50Pc pre
Fbccnv8403m00212                    B50Pc pre
Fbccnv8498m00012                    B50Pc pre
Fbccnv91051    2                    B50Pc pre
Fbccnv91801    2                    B50Pc pre
Fbccnv9181m00012                    B50Pc pre
Fbccnv9182m00012                    B50Pc pre
Fbccnv9442m00012                    B50Pc pre
Fbccnv9582m00012                    B50Pc pre
Fbcgct0100m00022                    B50Pc pre
Fbcgct0100m00032                    B50Pc pre
Fbcgct0101m00022                    B50Pc pre
Fbcgct0103m00012                    B50Pc pre
Fbcgct0106m00012                    B50Pc pre
Fbcgct5103m00012                    B50Pc pre
Fbcgct8170m00012                    B50Pc pre
Fbcgct9188m00012                    B50Pc pre
Fbcgct9189m00012                    B50Pc pre
Fbcgct91901    2                    B50Pc pre
Fbcgct9190m00012                    B50Pc pre
Fbcgct9191m00012                    B50Pc pre
Fbcgct9291m10012                    B50Pc pre
Fbcrun4220m00012                    B50Pc pre
Fbcrun4220m00022                    B50Pc pre
Fbcrun4520m00022                    B50Pc pre
Fbcrun5125m00012                    B50Pc pre
Fbcrun9087m00022                    B50Pc pre
Fbcrun9499m00012                    B50Pc pre
Fbcrun9499m000d2                    B50Pc pre
Fbcstc0114m00012                    B50Pc pre
Mbccnvdebug   12                    B50Pc pre
Mbccnvsimulate12                    B50Pc pre
Mbcgctchecklst12                    B50Pc pre
Mbcgctconvert 12                    B50Pc pre
Mbcgctesetup  12                    B50Pc pre
Mbcgctprocedur12                    B50Pc pre
Mbcgctprocess 12                    B50Pc pre
Mbcgctreports 12                    B50Pc pre
Mbcgctutility112                    B50Pc pre
Mbcgctutility212                    B50Pc pre
Mbcsbp0000100112                    B50Pc pre
Mbcsci0000100212                    B50Pc pre
Mbcsci0000200112                    B50Pc pre
Mbcsec0000100112                    B50Pc pre
Mbcsqm0000100112                    B50Pc pre
Mbcstc0000000112                    B50Pc pre
Mbcstc0000100112                    B50Pc pre
Mbcstc0000200112                    B50Pc pre
Mbcstc1000000012                    B50Pc pre
Mbcstd0000100212                    B50Pc pre
Mbcstf0000100112                    B50Pc pre
Mbcstf0000100212                    B50Pc pre
Mbcstf0000200112                    B50Pc pre
Mbcsti0000100112                    B50Pc pre
Mbcstp0000100112                    B50Pc pre
Mbcstp0000100212                    B50Pc pre
Mbcstp0000200112                    B50Pc pre
Mbcsts0000100112                    B50Pc pre
Mbcsts0000100212                    B50Pc pre
Mbcswh0000100112                    B50Pc pre
Mbcswh0000100212                    B50Pc pre
Mbcswh0000200112                    B50Pc pre
hbcSEstc0108m000                    B50Pc pre
